@@ -48,6 +48,7 @@ ALL_HASHES = (
 
 # we disable curves <= 256 bits by default in Fedora
 ALL_GROUPS = (
+    'X25519-MLKEM768', 'P256-MLKEM768', 'P384-MLKEM1024',
     'X25519', 'SECP256R1', 'SECP384R1', 'SECP521R1', 'X448',
     'FFDHE-1536', 'FFDHE-2048', 'FFDHE-3072', 'FFDHE-4096',
     'FFDHE-6144', 'FFDHE-8192', 'FFDHE-1024',
@@ -57,6 +58,7 @@ ALL_GROUPS = (
 )
 
 ALL_SIGN = (
+    'MLDSA44', 'MLDSA65', 'MLDSA87',
     'RSA-MD5', 'RSA-SHA1', 'DSA-SHA1', 'ECDSA-SHA1',
     'RSA-SHA2-224', 'DSA-SHA2-224', 'ECDSA-SHA2-224',
     'RSA-SHA2-256', 'DSA-SHA2-256', 'ECDSA-SHA2-256',
@@ -80,6 +82,7 @@ ALL_SIGN = (
 )
 
 ALL_KEY_EXCHANGES = (
+    'KEM-ECDH',
     'PSK', 'DHE-PSK', 'ECDHE-PSK', 'RSA-PSK', 'ECDHE',
     'RSA', 'DHE', 'DHE-RSA', 'DHE-DSS', 'EXPORT', 'ANON',
     'DH', 'ECDH',
